<?php
/**
 * Add the top level menu page.
 */
function socialsql_options_page() {
    add_menu_page(
        'SocialSQL',
        'SocialSQL',
        'manage_options',
        'socialsql_options',
        'socialsql_options_page_handler'
    );
}
 
 
/**
 * Register our socialsql_options_page to the admin_menu action hook.
 */
add_action( 'admin_menu', 'socialsql_options_page' );

add_action( 'admin_enqueue_scripts', 'socialsql_admin_scripts' );

function socialsql_admin_scripts() {
    wp_enqueue_style ('wp-jquery-ui-dialog');
    wp_enqueue_style ('socialsql-admin-style');
    wp_localize_script('socialsql-add-source-modal', 'socialsqlAdmin', array('ajaxurl' => admin_url('admin-ajax.php')));
    wp_enqueue_script ('socialsql-add-source-modal');
    wp_enqueue_script('socialsql-sources-table');
}

add_action( 'wp_ajax_socialsql_getpagetoken', 'socialsql_getpagetoken' );
add_action( 'wp_ajax_socialsql_getpagedata', 'socialsql_getpagedata' );

/**
 * Top level menu callback function
 */ 
function socialsql_options_page_handler() {
    global $wpdb; 
    $sources_table_name = $wpdb->prefix . 'socialsql_sources';
?>    
    <div class="wrap">
      <div class="meta-box-sortables ui-sortable">
        <h2>Facebook Feed Sources</h2>
        <button id="open-modal" class="button" style="display: none;">open modal</button>
        <div id="modal-content"></div>
        <div id="loader"></div>
        <form method="POST" action="?page=socialsql_options">
          <input name="addsource" class="button" type="submit" value="Add Source" style="float:right"></input>
        </form>
    
        <form method="post">
          <input type="hidden" name="page" value="socialsql_options" />
          <?php
            $sources_table = new SocialSQL_Sources_Table();
            $sources_table->prepare_items();
            $sources_table->display();
          ?>
        </form>
      </div>
    </div>
    
<?php
    // check user capabilities
    if ( ! current_user_can( 'manage_options' ) ) {
        return;
    }

    if (get_site_transient('socialsql_callback_data')) {
        $pages = json_decode(get_site_transient('socialsql_callback_data'), true);
        $content = "";
        foreach ($pages as $page) {
		    $content .= "<input type='radio' id='".$page["id"]."' name='page' value='".$page["id"]."'>";
		    $content .= "<label for='".$page["id"]."'>".$page['name']."</label><br>";
		};
?>
        <script>
        jQuery(document).ready(function($) {
            $( "#open-modal" ).trigger( "click" );
            $( "#modal-content" ).html("<?php echo $content; ?>");
        });
        </script>
<?php
        delete_site_transient('socialsql_callback_data');
    }
?>   
        
    <?php
}

function socialsql_submit_handler() {
    if ($_SERVER["REQUEST_METHOD"] == "POST") {

        if (isset($_POST['addsource'])){
            $currentUrl = socialsql_getcurrenturl();
          	$siteUrl = get_site_url();
            wp_redirect(constant('socialsql_server').'/fbapp/api/user/login?callback_url='.$currentUrl.'&site_url='.$siteUrl);
            exit;
        }

    }
}
add_action( 'wp_loaded', 'socialsql_submit_handler');

/* submit handler for add-source-modal */
function socialsql_getpagetoken() {
    global $wpdb;
	$table_name = $wpdb->prefix . 'socialsql_sources';
    $pageid = $_POST['pageid'];
    $row = $wpdb->get_row( "SELECT * FROM $table_name WHERE page_id = $pageid" );
    
    if (!empty($row)) {
        echo 'exist';
    }
  	else {
    	$post_url = constant('socialsql_server').'/fbapp/api/user/getpagetoken';
    	$ch = curl_init();
    	curl_setopt($ch, CURLOPT_URL, $post_url);
    	curl_setopt($ch, CURLOPT_POST, 1);
    	$headers = array(
        	"Content-Type: application/json",
    	);
    	curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    	$data = '{"pageid": "'.$pageid.'","token":"'.get_site_transient('socialsql_callback_token').'"}';
    	curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
    	curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    	$result = curl_exec($ch);
    	curl_close($ch);
    	$page = json_decode($result, true);
    	$source['page_id'] = $page['id'];
    	$source['page_name'] = $page['name'];
    	$source['access_token'] = $page['token'];
    	$where_source['page_id'] = $pageid;
    
    	$update = SocialSQL_DB::update_source($source, $where_source);
    	if ($update === FALSE || $update < 1) {
        	$error = SocialSQL_DB::insert_source($source);
        	// check for error here to make sure data is written to DB
        	//echo 'error:'.$error;
    	}
    	echo $result;
    }
    exit;
}

if ( ! wp_next_scheduled( 'socialsql_cron_hook' ) ) {
    wp_schedule_event( time(), 'twicedaily', 'socialsql_cron_hook' );
}
add_action( 'socialsql_cron_hook', 'socialsql_cron_getpagedata' );

// Cron task that runs all getpagedata for all pageids
function socialsql_cron_getpagedata() {
    global $wpdb;
	$table_name = $wpdb->prefix . 'socialsql_sources';
    $results = $wpdb->get_results( "SELECT * FROM $table_name" );
   
    foreach ($results as $result) {
        $pageid = $result->page_id;
        $token = $result->access_token;
        socialsql_args_getpagedata($pageid, $token);
    }
    // Error handling here if required
    exit;
}

function socialsql_getpagedata() {
    
    global $wpdb;
	$table_name = $wpdb->prefix . 'socialsql_sources';
    $pageid = $_POST['pageid'];
    $row = $wpdb->get_row( "SELECT * FROM $table_name WHERE page_id = $pageid" );
    
    if (!empty($row)) {
        $token = $row->access_token;
        socialsql_args_getpagedata($pageid, $token);
    }
    // Error handling here if required
    exit;
}

function socialsql_args_getpagedata($pageid, $token) {
    
    $post_url = constant('socialsql_server').'/fbapp/api/user/getpagedata';
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $post_url);
    curl_setopt($ch, CURLOPT_POST, 1);
    $headers = array(
        "Content-Type: application/json",
    );
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    $data = '{"pageid": "'.$pageid.'","token":"'.$token.'"}';
    curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    $result = curl_exec($ch);
    curl_close($ch);
        
    if($result != false) {
        $page = json_decode($result, true);
        $source['last_updated'] = $page['last_updated'];
        $where_source['page_id'] = $page['page_id'];
        $update = SocialSQL_DB::update_source($source, $where_source);
    }
        
    echo $result;
}

function socialsql_getcurrenturl() {
    $protocol = is_ssl() ? 'https://' : 'http://';
    return ($protocol) . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'];
}

add_action( 'rest_api_init', 'socialsql_register_api_hooks' );
// API custom endpoints for WP-REST API
function socialsql_register_api_hooks() {
    register_rest_route(
        'socialsql', '/login/',
        array(
            //'methods'  => 'GET, POST',
            'methods'  => 'POST',
            'callback' => 'socialsql_login',
        )
    );
}

function socialsql_login($request) {
    $data = json_decode(file_get_contents('php://input'), true);
    $pages = json_encode($data['page']);
    $token = $data['token'];
    set_site_transient('socialsql_callback_data', $pages, 86400 );
    set_site_transient('socialsql_callback_token', $token, 86400 );
    echo $data;
}

?>
