<?php
if (!class_exists('WP_List_Table')) {
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

class SocialSQL_Sources_Table extends WP_List_Table {

    // Class constructor
    public function __construct() {

		parent::__construct( [
			'singular' => 'SocialSQL_Source', //singular name of the listed records
			'plural' => 'SocialSQL_Sources', //plural name of the listed records
			'ajax' => false //should this table support ajax?

		] );
	}

	public static function get_socialsql_sources() {
		global $wpdb;
        $table_name = $wpdb->prefix . 'socialsql_sources';
		$result = $wpdb->get_results( "SELECT page_name, page_id, last_updated FROM $table_name", ARRAY_A );
		for ($i = 0; $i < count($result); $i++) {
            $result[$i]['last_updated'] = get_date_from_gmt($result[$i]['last_updated'], get_option('time_format') . ' ' . get_option('date_format'));
        }
        return $result;
	}
	
	public static function delete_source( $id ) {
	    SocialSQL_DB::delete_source($id);
    }

	// Returns the count of records in the database.
	public static function record_count() {
		global $wpdb;
        $table_name = $wpdb->prefix . 'socialsql_sources';
		$result = $wpdb->get_var("SELECT COUNT(*) FROM $table_name");
		return $result;
	}

	// Text displayed when no customer data is available
	public function no_items() {
		_e( 'No Facebook Page Has Been Added To Sources.', 'socialsql' );
	}

	function column_page_name( $item ) {
		// create a nonce
        $action_nonce = wp_create_nonce( 'socialsql_source_action' );

        $title = '<strong>' . $item['page_name'] . '</strong>';

        $actions = [
            'delete' => sprintf( '<a href="?page=%s&action=%s&source=%s&_wpnonce=%s">Delete</a>', esc_attr( $_REQUEST['page'] ), 'delete', absint( $item['page_id'] ), $action_nonce ),
            'refresh' => sprintf( '<a class="socialsql_refresh_source" href="#" data-page_id="%s">Refresh</a>', absint( $item['page_id'] ))
        ];

        return $title . $this->row_actions( $actions );
	}
	
	function column_cb( $item ) {
        return sprintf('<input type="checkbox" name="bulk-delete[]" value="%s" />', $item['page_id']);
    }

	// Render a column when no column specific method exists.
	public function column_default( $item, $column_name ) {
		switch ( $column_name ) {
            case 'page_name':
			case 'page_id':
			case 'last_updated':
				return $item[ $column_name ];
			default:
				return print_r( $item, true ); //Show the whole array for troubleshooting purposes
		}
	}

	// Associative array of columns
	function get_columns() {
		$columns = [
			'cb' => '<input type="checkbox" />',
			'page_name' => 'Page Name',
			'page_id' => 'Page ID',
			'last_updated' => 'Last Updated',
		];

		return $columns;
	}

    public function get_hidden_columns()
    {
        return array();
    }
    
    public function get_sortable_columns() {
		return array();
	}
    
    public function get_bulk_actions() {
        $actions = [
            'bulk-delete' => 'Delete'
        ];

        return $actions;
    }
    
    public function process_bulk_action() {

        //Detect when a bulk action is being triggered...
        if ( 'delete' === $this->current_action() ) {

            // In our file that handles the request, verify the nonce.
            $nonce = esc_attr( $_REQUEST['_wpnonce'] );

            if ( ! wp_verify_nonce( $nonce, 'socialsql_source_action' ) ) {
                die( 'Go get a life script kiddies' );
            }
            else {
                self::delete_source( absint( $_GET['source'] ) );
                //redirect is not working, manually refresh the table after delete
                //wp_redirect( esc_url( add_query_arg() ) );
                self::refresh_table();
                exit;
            }

        }

        // If the delete bulk action is triggered
        if ( ( isset( $_POST['action'] ) && $_POST['action'] == 'bulk-delete' )
        || ( isset( $_POST['action2'] ) && $_POST['action2'] == 'bulk-delete' )
        ) {
            
            $delete_ids = esc_sql( $_POST['bulk-delete'] );

            // loop over the array of record IDs and delete them
            foreach ( $delete_ids as $id ) {
                self::delete_source( $id );
            }
            
            //redirect is not working, manually refresh the table after delete  
            //wp_redirect( esc_url( add_query_arg() ) );
            self::refresh_table();
            exit;
        }
    }
    
	public function prepare_items() {
	    $this->process_bulk_action();
	    $columns = self::get_columns();
        $hidden = self::get_hidden_columns();
        $sortable = self::get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);
        
	    $this->items = self::get_socialsql_sources();
	}
	
	// Workaround function for table actions until better solution is found
	public function refresh_table() {
	    $columns = self::get_columns();
        $hidden = self::get_hidden_columns();
        $sortable = self::get_sortable_columns();
        $this->_column_headers = array($columns, $hidden, $sortable);
	    $this->items = self::get_socialsql_sources();
	    self::display();
	}
}

?>